pub fn validate_sql(sql: &str) -> Result<(), SqlValidationError>Expand description
Validate any SQL statement by detecting its type and applying appropriate rules
pub fn validate_sql(sql: &str) -> Result<(), SqlValidationError>Validate any SQL statement by detecting its type and applying appropriate rules