pub struct DefaultWebSocketHandler { /* private fields */ }Expand description
Default WebSocket handler that tracks connections and echoes messages.
- Text messages are echoed back to the sender with the sender’s user_id.
- Ping messages are answered with a Pong.
- Subscribe/Unsubscribe/Join/Leave messages return a System acknowledgement.
- All other messages are logged but produce no response.
Implementations
Sourceimpl DefaultWebSocketHandler
impl DefaultWebSocketHandler
pub fn new() -> DefaultWebSocketHandler
pub async fn connection_count(&self) -> usize
pub async fn is_connected(&self, connection_id: &str) -> bool
pub async fn message_count(&self) -> usize
pub async fn messages(&self) -> Vec<WebSocketMessage>
pub async fn get_connection( &self, connection_id: &str, ) -> Option<WebSocketConnection>