pub struct ErrorRateCounter { /* private fields */ }Expand description
Error rate counter, based on a sliding time window for error rate statistics.
Samples outside the window are evicted on the next record call,
ensuring rate() is always computed from the latest samples within the window.
Implementations